/**
 * @file scp_client_misc.h
 * @brief Helper functions for SCP client
 *
 * @section License
 *
 * Copyright (C) 2010-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneSSH Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _SCP_CLIENT_MISC_H
#define _SCP_CLIENT_MISC_H

//Dependencies
#include "scp/scp_client.h"

//C++ guard
#ifdef __cplusplus
extern "C" {
#endif

//SCP client related functions
void scpClientChangeState(ScpClientContext *context,
   ScpClientState newState);

error_t scpClientOpenConnection(ScpClientContext *context);
error_t scpClientEstablishConnection(ScpClientContext *context);
void scpClientCloseConnection(ScpClientContext *context);

error_t scpClientSendDirective(ScpClientContext *context,
   const ScpDirective *directive);

error_t scpClientReceiveDirective(ScpClientContext *context,
   ScpDirective *directive);

error_t scpClientProcessEvents(ScpClientContext *context);
error_t scpClientCheckTimeout(ScpClientContext *context);

//C++ guard
#ifdef __cplusplus
}
#endif

#endif
