/**
 * @file ssh_cert_import.h
 * @brief SSH certificate import functions
 *
 * @section License
 *
 * Copyright (C) 2010-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneSSH Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _SSH_CERT_IMPORT_H
#define _SSH_CERT_IMPORT_H

//Dependencies
#include "ssh_types.h"
#include "ssh_cert_parse.h"
#include "pkc/rsa.h"
#include "pkc/dsa.h"
#include "ecc/ec.h"
#include "ecc/eddsa.h"

//C++ guard
#ifdef __cplusplus
extern "C" {
#endif

//SSH certificate import functions
error_t sshImportCertificate(const char_t *input, size_t inputLen,
   uint8_t *output, size_t *outputLen);

error_t sshImportRsaCertPublicKey(const SshCertificate *cert,
   RsaPublicKey *publicKey);

error_t sshImportDsaCertPublicKey(const SshCertificate *cert,
   DsaPublicKey *publicKey);

error_t sshImportEcdsaCertPublicKey(const SshCertificate *cert,
   EcDomainParameters *params, EcPublicKey *publicKey);

error_t sshImportEd25519CertPublicKey(const SshCertificate *cert,
   EddsaPublicKey *publicKey);

const char_t *sshGetCertType(const char_t *input, size_t length);

//C++ guard
#ifdef __cplusplus
}
#endif

#endif
