/**
 * @file ssh_exchange_hash.h
 * @brief Exchange hash calculation
 *
 * @section License
 *
 * Copyright (C) 2010-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneSSH Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _SSH_EXCHANGE_HASH_H
#define _SSH_EXCHANGE_HASH_H

//Dependencies
#include "ssh/ssh.h"

//C++ guard
#ifdef __cplusplus
extern "C" {
#endif

//SSH related functions
error_t sshInitExchangeHash(SshConnection *connection);

error_t sshUpdateExchangeHash(SshConnection *connection, const void *data,
   size_t length);

error_t sshFinalizeExchangeHash(SshConnection *connection, uint8_t *digest,
   size_t *digestLen);

error_t sshUpdateExchangeHashRaw(SshConnection *connection, const void *data,
   size_t length);

error_t sshGenerateExchangeHashSignature(SshConnection *connection,
   uint8_t *p, size_t *written);

error_t sshVerifyExchangeHashSignature(SshConnection *connection,
   const SshBinaryString *serverHostKey, const SshBinaryString *signature);

//C++ guard
#ifdef __cplusplus
}
#endif

#endif
