/**
 * @file key_exch_algorithms.h
 * @brief Collection of key exchange algorithms
 *
 * @section License
 *
 * Copyright (C) 2010-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 3.0.6
 **/

#ifndef _KEY_EXCH_ALGORITHMS_H
#define _KEY_EXCH_ALGORITHMS_H

//Dependencies
#include "core/crypto.h"

//Diffie-Hellman support?
#if (DH_SUPPORT == ENABLED)
   #include "pkc/dh.h"
#endif

//ECDH support?
#if (ECDH_SUPPORT == ENABLED)
   #include "ecc/ecdh.h"
#endif

//KEM support?
#if (KEM_SUPPORT == ENABLED)
   #include "pqc/kem.h"
#endif

#endif
